/* Modified from ProtoSnap LilyPad Development Platform Example Code
  by: Pete Lewis SparkFun Electronics
  license: Creative Commons Attribution-Share-alike v3.0 CC BY-SA 3.0
  http://creativecommons.org/licenses/by-sa/3.0/
  
  This is example code for the Protosnap LilyPad Development Platform modified
  by Sylvia Martinez for Invent To Learn workshops http://inventtolearn.com
  
  The code defines the pins for the LEDs, buzzers, etc that come with the ProtoSnap
  
  It'll do a quick startup sequence, flashing all LEDs, then it'll go int the loop.
  In the loop it'll check for button or switch presses, and buzz or vibrate
  depending on if they're engaged.
  If neither switch is on, it'll check the light sensor and temperature sensor,
  and light up some LEDs if it's dark enough. Hold your finger over the
  light sensor to block the light and turn the white LEDs on. 
  Try blowing on the temperature sensor to turn the red LED on.
  Finally, the status of each input is streamed over the serial line at 9600 bps.
  To see what the values are, open up the serial monitor (the top right icon)
  and make sure the baud is set to 9600.
*/

/* Pin Definitions */
// LEDs: white LEDs are connected to 5, 6, A2, A3, A4
// naming your pins means you can use the name instead of having to put the pin
// number in every time you use it in the code that follows. it also means you 
// can resuse the code with other projects that might have the LEDs on different pins
// and you only have to change the pin number once at the top of the sketch

int ledwhite1 = 5;
int ledwhite2 = 6;
int ledwhite3 = A2;
int ledwhite4 = A4;
int ledwhite5 = A3;

int ledred = 9;
int ledgreen = 10;
int ledblue = 11;
int switchPin = 2;
int buttonPin = A5;
int vibePin = 3;
int buzzerP = 7;
int buzzerN = 12;
int lightSensorPin = A6;
int tempSensorPin = A1;

/* Global variables */
// test your ambient ligh reading on the Serial Monitor (click the button
// in the IDE upper right corner that looks like a magnifying glass). Any "print"
// commands will show in the Serial Monitor
// when you know what your light sensor reads in "normal" or "ambient" conditions
// put that number here. global variables can be used anywhere in this sketch
int ambientlight = 300;

void setup()
{
  //STARTUP LED SEQUENCE
  {  // blink the white LEDs
    pinMode(ledwhite1, OUTPUT);  // set pin as output
    digitalWrite(ledwhite1, HIGH);  // turn LED on
    delay(250);  // wait for a quarter second
    digitalWrite(ledwhite1, LOW); // turn LED off
    
    pinMode(ledwhite2, OUTPUT);  // set pin as output
    digitalWrite(ledwhite2, HIGH);  // turn LED on
    delay(250);  // wait for a quarter second
    digitalWrite(ledwhite2, LOW); // turn LED off
    
    pinMode(ledwhite3, OUTPUT);  // set pin as output
    digitalWrite(ledwhite3, HIGH);  // turn LED on
    delay(250);  // wait for a quarter second
    digitalWrite(ledwhite3, LOW); // turn LED off
    
    pinMode(ledwhite4, OUTPUT);  // set pin as output
    digitalWrite(ledwhite4, HIGH);  // turn LED on
    delay(250);  // wait for a quarter second
    digitalWrite(ledwhite4, LOW); // turn LED off
    
    pinMode(ledwhite5, OUTPUT);  // set pin as output
    digitalWrite(ledwhite5, HIGH);  // turn LED on
    delay(250);  // wait for a quarter second
    digitalWrite(ledwhite5, LOW); // turn LED off
 
   // blink the RGB LEDs 
    pinMode(ledred, OUTPUT);   // set the pin as an output 
    digitalWrite(ledred, LOW);  // turn RGB LED on red
    delay(250);  // wait a quarter second
    digitalWrite(ledred, HIGH);  // turn the RGB LED off
    
    pinMode(ledgreen, OUTPUT);   // set the pin as an output 
    digitalWrite(ledgreen, LOW);  // turn RGB LED on red
    delay(250);  // wait a quarter second
    digitalWrite(ledgreen, HIGH);  // turn the RGB LED off
    
    pinMode(ledblue, OUTPUT);   // set the pin as an output 
    digitalWrite(ledblue, LOW);  // turn RGB LED on red
    delay(250);  // wait a quarter second
    digitalWrite(ledblue, HIGH);  // turn the RGB LED off
    
    // Note that a HIGH turns the RGB LED off, LOW is on
    // that's backwards from the white LEDs
  }
  ////////////////////////////////////////////

  //Switch
  pinMode(switchPin, INPUT);  // set the switch as an input
  digitalWrite(switchPin, HIGH);  // enable the pull-up resistor

  //Button
  pinMode(buttonPin, INPUT);  // set the pin as an input
  digitalWrite(buttonPin, HIGH);  // enable the pull-up resistor

  //VIBE
  pinMode(vibePin, OUTPUT);  // set the pin as an output

  //Buzzer
  pinMode(buzzerP, OUTPUT);  // set both buzzer pins as outputs
  pinMode(buzzerN, OUTPUT);

  Serial.begin(9600);  // We'll output some information over serial
}

void loop()
{
  //Buzzer
  if(digitalRead(buttonPin) == 0)
  {  // if you press the button, make a short buzz
    digitalWrite(buzzerP, HIGH);
    digitalWrite(buzzerN, LOW);
    delay(1);
    digitalWrite(buzzerP, LOW);
    digitalWrite(buzzerN, HIGH);
  }
  else  // If the button is not pressed go in here
  {
    if(digitalRead(switchPin) == 0)
    {  // If the switch is on, vibrate
      digitalWrite(vibePin, HIGH);
      delay(100);
      digitalWrite(vibePin, LOW); 
    }
    
    ///LIGHT TEST
    if(analogRead(lightSensorPin) < ambientlight){
      //if its dark, turn on all white leds...
        digitalWrite(ledwhite1, HIGH);
        digitalWrite(ledwhite2, HIGH);
        digitalWrite(ledwhite3, HIGH);
        digitalWrite(ledwhite4, HIGH);
        digitalWrite(ledwhite5, HIGH);
    }
    else{
      // if it's light, turn them off...
 
      {
        digitalWrite(ledwhite1, LOW);
        digitalWrite(ledwhite2, LOW);
        digitalWrite(ledwhite3, LOW);
        digitalWrite(ledwhite4, LOW);
        digitalWrite(ledwhite5, LOW);
      }
    }

    ///TEMP TEST is the temperature sensor reading going up?
    if(analogRead(tempSensorPin) > 160)
    {
      //if the tech puts a little hot air over the temp sensor it will raise to at least 170
      digitalWrite(ledred, LOW); //Turn on red LED - to indicate "hot"
    }
    else{
      digitalWrite(ledred, HIGH);  // turn the red LED off
    }
    
    /* from here on down, we'll just print out the status of every input */
    Serial.print("Switch=");
    Serial.print(digitalRead(switchPin));

    Serial.print("  Temp=");
    Serial.print(analogRead(tempSensorPin));
    
    Serial.print("  Button=");
    Serial.print(digitalRead(buttonPin));

    Serial.print("  Light=");
    Serial.println(analogRead(lightSensorPin)); 
  }
}
// Challenge: change the code so that instead of turning the white LEDs on when it's dark, turn them
// on when it's light.
//
// Extension: Using 4 lines of code to turn every LED on and off separately is inefficient.
// See the LilyPad Development Example sketch https://www.sparkfun.com/datasheets/DevTools/LilyPad/lilypad_dev_v11.pde
// to see how to use arrays to define the pins and a for loop to turn on the LEDs as
// they are listed in the array.

// Challenge: change the code so that the white LEDs light up one at a time to show how much light the light sensor
// is detecting.

// Challenge: change the code to output actual temperature readings to the serial monitor.
