/*
  Modified from Pitch Follower by Tom Igoe
 
 http://arduino.cc/en/Tutorial/Tone2
 
 Modified by Sylvia Martinez for Invent To Learn workshops using 
 the Lilypad Protosnap development board. http://inventtolearn.com
 
 The buzzer will react to light shined on the light sensor with a rising tone.
 
 The "serial.print" command writes the value of the light sensor reading
 in the Serial Monitor Window of the Arduino IDE. Click on the button that
 looks like a magnifying glass in the upper right window of this sketch.
 
 The light sensor (pin A6) gives a value between 0 - 1023.
 The buzzer (pin 7) plays a tone of any frequency
 
 The if/else tests whether the light sensor is reading above the ambient light level
 Otherwise the buzzer will buzz all the time and that's annoying.
 
 To find the ambient light level, turn on the Serial Montitor and see what
 value it is reading. Set the sensorReading in the if statement (now 400) to that
 value or a little higher.
 
 Extension: Sending the sensor reading directly to the buzzer as pitch is a bit of
 a kludge. See the original Pitch follower code http://arduino.cc/en/Tutorial/Tone2
 to find out how to "map" (or normalize) a range of input values into a different 
 range of output values.
 
 Challenge: How high can the buzzer frequency go? What is the range of human hearing?
 
 Extension: Find out more about how to make musical notes with different frequencies and 
 durations in this tutorial sketch http://arduino.cc/en/Tutorial/Tone
 
 */


void setup() {
  // initialize serial communications (for debugging only):
  Serial.begin(9600);
}

void loop() {
  // read the light sensor on pin A6:
  int sensorReading = analogRead(A6);
  // print the sensor reading in the Serial Monitor so you know its range
  Serial.println(sensorReading);

  // play the pitch on the buzzer (pin 7)
  
  if (sensorReading > 300)   // change this value to ambient light reading
{
  tone(7, sensorReading, 10);
  delay(1);        // delay in between reads for stability
}
else
{
 noTone(7); // if the light sensor is reading ambient light, buzzer will not buzz
}
 
 
}
